#' @importFrom utils bibentry
bibentries  = c(
  precrec   = bibentry("article",
    title   = "Precrec: fast and accurate precision-recall and ROC curve calculations in R",
    author  = "Takaya Saito and Marc Rehmsmeier",
    journal = "Bioinformatics",
    year    = "2017",
    volume  = "33",
    number  = "1",
    pages   = "145-147",
    doi     = "10.1093/bioinformatics/btw570",
  ),

  ggfortify = bibentry("article",
    author  = "Yuan Tang and Masaaki Horikoshi and Wenxuan Li",
    title   = "ggfortify: Unified Interface to Visualize Statistical Result of Popular R Packages",
    journal = "The R Journal",
    year    = "2016",
    pages   = "474--485",
    number  = "2",
    volume  = "8",
    doi     = "10.32614/RJ-2016-060"
  ),

  dcalib = bibentry("article",
    author  = "Humza Haider and Bret Hoehn and Sarah Davis and Russell Greiner",
    title   = "Effective Ways to Build and Evaluate Individual Survival Distributions",
    journal = "Journal of Machine Learning Research",
    year    = "2020",
    volume  = "21",
    number  = "85",
    pages   = "1-63",
    url     = "https://jmlr.org/papers/v21/18-772.html"
  )
)
